@@ -19,10 +19,13 @@ class RolesConfig extends IniRepository
     {
         $columns = [
             'roles' => [
+                'parent',
                 'name',
                 'users',
                 'groups',
+                'refusals',
                 'permissions',
+                'unrestricted',
                 'application/share/users',
                 'application/share/groups'
             ]
@@ -37,4 +40,9 @@ class RolesConfig extends IniRepository
 
         return $columns;
     }
+
+    protected function initializeSearchColumns(): array
+    {
+        return ['name'];
+    }
 }
