@@ -11,6 +11,7 @@ use Icinga\Exception\AuthenticationException;
 use Icinga\Repository\DbRepository;
 use Icinga\User;
 use PDO;
+use Zend_Db_Expr;
 
 class DbUserBackend extends DbRepository implements UserBackendInterface, Inspectable
 {
@@ -21,7 +22,7 @@ class DbUserBackend extends DbRepository implements UserBackendInterface, Inspec
      */
     protected $queryColumns = array(
         'user' => array(
-            'user'          => 'name COLLATE utf8_general_ci',
+            'user'          => 'name COLLATE utf8mb4_general_ci',
             'user_name'     => 'name',
             'is_active'     => 'active',
             'created_at'    => 'UNIX_TIMESTAMP(ctime)',
@@ -179,16 +180,24 @@ class DbUserBackend extends DbRepository implements UserBackendInterface, Inspec
     {
         if ($this->ds->getDbType() === 'pgsql') {
             // Since PostgreSQL version 9.0 the default value for bytea_output is 'hex' instead of 'escape'
-            $columns = array('password_hash' => 'ENCODE(password_hash, \'escape\')');
+            $columns = ['password_hash' => new Zend_Db_Expr('ENCODE(password_hash, \'escape\')')];
         } else {
-            $columns = array('password_hash');
+            $columns = ['password_hash'];
         }
 
-        $query = $this->ds->select()
-            ->from($this->prependTablePrefix('user'), $columns)
-            ->where('name', $username)
+        $nameColumn = 'user';
+        if ($this->ds->getDbType() === 'mysql') {
+            $username = strtolower($username);
+            $nameColumn = new Zend_Db_Expr('BINARY LOWER(name)');
+        }
+
+        $query = $this
+            ->select()
+            ->from('user', $columns)
+            ->where($nameColumn, $username)
             ->where('active', true);
-        $statement = $this->ds->getDbAdapter()->prepare($query->getSelectQuery());
+
+        $statement = $this->ds->getDbAdapter()->prepare($query->getQuery()->getSelectQuery());
         $statement->execute();
         $statement->bindColumn(1, $lob, PDO::PARAM_LOB);
         $statement->fetch(PDO::FETCH_BOUND);
@@ -196,6 +205,10 @@ class DbUserBackend extends DbRepository implements UserBackendInterface, Inspec
             $lob = stream_get_contents($lob);
         }
 
+        if ($lob === null) {
+            return '';
+        }
+
         return $this->ds->getDbType() === 'pgsql' ? pg_unescape_bytea($lob) : $lob;
     }
 
